@@ -4,7 +4,8 @@ use warnings;
 
 package CPAN::Testers::Fact::TestEnvironment;
 # ABSTRACT: Environment vars and other local context during a CPAN Testers report
-our $VERSION = '1.999002'; # VERSION
+
+our $VERSION = '1.999003';
 
 use Carp ();
 
@@ -40,11 +41,11 @@ CPAN::Testers::Fact::TestEnvironment - Environment vars and other local context
 
 =head1 VERSION
 
-version 1.999002
+version 1.999003
 
 =head1 SYNOPSIS
 
-  my $fact = CPAN::Testers::Fact::TestEnvironment>new(
+  my $fact = CPAN::Testers::Fact::TestEnvironment->new(
     resource => 'cpan:///distfile/RJBS/CPAN-Metabase-Fact-0.001.tar.gz',
     content     => {
       environment_vars => {
@@ -83,7 +84,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by David Golden.
+This software is Copyright (c) 2015 by David Golden.
 
 This is free software, licensed under:
 
